pub struct PackageBlueprintVersionRoyaltyConfigEntryPayload { /* private fields */ }Expand description
This new type represents the payload of a particular field or collection. It is unique to this particular field/collection.
Therefore, it can be used to disambiguate if the same content type is used by different blueprints (e.g. two different versions of the same blueprint)
Implementations
Sourceimpl PackageBlueprintVersionRoyaltyConfigEntryPayload
impl PackageBlueprintVersionRoyaltyConfigEntryPayload
pub fn of(content: VersionedPackageBlueprintVersionRoyaltyConfig) -> Self
Sourceimpl PackageBlueprintVersionRoyaltyConfigEntryPayload
impl PackageBlueprintVersionRoyaltyConfigEntryPayload
Sourcepub fn fully_update(self) -> Self
pub fn fully_update(self) -> Self
Sourcepub fn fully_update_and_into_latest_version(
self,
) -> PackageBlueprintVersionRoyaltyConfig
pub fn fully_update_and_into_latest_version( self, ) -> PackageBlueprintVersionRoyaltyConfig
Sourcepub fn from_latest_version(
latest_version: PackageBlueprintVersionRoyaltyConfig,
) -> Self
pub fn from_latest_version( latest_version: PackageBlueprintVersionRoyaltyConfig, ) -> Self
Sourcepub fn into_unique_version(self) -> PackageBlueprintVersionRoyaltyConfig
pub fn into_unique_version(self) -> PackageBlueprintVersionRoyaltyConfig
Sourcepub fn from_unique_version(
unique_version: PackageBlueprintVersionRoyaltyConfig,
) -> Self
pub fn from_unique_version( unique_version: PackageBlueprintVersionRoyaltyConfig, ) -> Self