pub struct RemoveMetadataEvent {
pub key: String,
}Fields
key: StringTrait Implementations
Sourceimpl Debug for RemoveMetadataEvent
impl Debug for RemoveMetadataEvent
Sourceimpl<D: Decoder<ScryptoCustomValueKind>> Decode<ScryptoCustomValueKind, D> for RemoveMetadataEvent
impl<D: Decoder<ScryptoCustomValueKind>> Decode<ScryptoCustomValueKind, D> for RemoveMetadataEvent
Sourcefn decode_body_with_value_kind(
decoder: &mut D,
value_kind: ValueKind<ScryptoCustomValueKind>,
) -> Result<Self, DecodeError>
fn decode_body_with_value_kind( decoder: &mut D, value_kind: ValueKind<ScryptoCustomValueKind>, ) -> Result<Self, DecodeError>
Decodes the type from the decoder, which should match a preloaded value kind. Read more
Sourceimpl Describe<ScryptoCustomTypeKind> for RemoveMetadataEvent
impl Describe<ScryptoCustomTypeKind> for RemoveMetadataEvent
Sourceconst TYPE_ID: RustTypeId
const TYPE_ID: RustTypeId
The
TYPE_ID should give a unique identifier for its SBOR schema type.
An SBOR schema type capture details about the SBOR payload, how it should be interpreted, validated and displayed. Read moreSourcefn type_data() -> TypeData<ScryptoCustomTypeKind, RustTypeId>
fn type_data() -> TypeData<ScryptoCustomTypeKind, RustTypeId>
Returns the local schema for the given type. Read more
Sourcefn add_all_dependencies(aggregator: &mut TypeAggregator<ScryptoCustomTypeKind>)
fn add_all_dependencies(aggregator: &mut TypeAggregator<ScryptoCustomTypeKind>)
For each type referenced in
get_local_type_data, we need to ensure that the type and all of its own references
get added to the aggregator. Read moreSourceimpl<E: Encoder<ScryptoCustomValueKind>> Encode<ScryptoCustomValueKind, E> for RemoveMetadataEvent
impl<E: Encoder<ScryptoCustomValueKind>> Encode<ScryptoCustomValueKind, E> for RemoveMetadataEvent
Sourcefn encode_value_kind(&self, encoder: &mut E) -> Result<(), EncodeError>
fn encode_value_kind(&self, encoder: &mut E) -> Result<(), EncodeError>
Encodes the SBOR value’s kind to the encoder
Sourcefn encode_body(&self, encoder: &mut E) -> Result<(), EncodeError>
fn encode_body(&self, encoder: &mut E) -> Result<(), EncodeError>
Encodes the SBOR body of the type to the encoder. Read more
Sourceimpl SborTuple<ScryptoCustomValueKind> for RemoveMetadataEvent
impl SborTuple<ScryptoCustomValueKind> for RemoveMetadataEvent
fn get_length(&self) -> usize
Sourceimpl ScryptoEvent for RemoveMetadataEvent
impl ScryptoEvent for RemoveMetadataEvent
const EVENT_NAME: &'static str = "RemoveMetadataEvent"