pub struct RoleAssignmentNativePackage;Implementations
Sourceimpl RoleAssignmentNativePackage
impl RoleAssignmentNativePackage
pub fn definition() -> PackageDefinition
pub fn invoke_export<Y: SystemApi<RuntimeError>>( export_name: &str, input: &IndexedScryptoValue, api: &mut Y, ) -> Result<IndexedScryptoValue, RuntimeError>
Sourcepub fn is_role_key_reserved(role_key: &RoleKey) -> bool
pub fn is_role_key_reserved(role_key: &RoleKey) -> bool
Checks if a role key is a reserved.
The system has reserved all role keys starting with _.
Sourcepub fn is_role_key_reserved_and_defined(role_key: &RoleKey) -> bool
pub fn is_role_key_reserved_and_defined(role_key: &RoleKey) -> bool
Checks if a role key is a reserved and has been defined.
Currently there are only two such roles, i.e. OWNER_ROLE and SELF_ROLE, which can be referenced in role list.
pub fn verify_access_rule( access_rule: &AccessRule, ) -> Result<(), RoleAssignmentError>
pub fn init_system_struct( owner_role: OwnerRoleEntry, roles: IndexMap<ModuleId, RoleAssignmentInit>, ) -> Result<(IndexMap<u8, FieldValue>, IndexMap<u8, IndexMap<Vec<u8>, KVEntry>>), RoleAssignmentError>