Module transaction

Module transaction 

Radix Engine transaction interface.

Structs

AbortResult
BalanceAccounter
Note that the implementation below assumes that substate owned objects can not be detached. If this changes, we will have to account for objects that are removed from a substate.
CommitResult
CostingParameters
Protocol-defined costing parameters
EventSchemaMapper
Note that the implementation below assumes that substate owned objects can not be detached. If this changes, we will have to account for objects that are removed from a substate.
EventSystemStructure
ExecutionConfig
FeeDestination
FeeLocks
FeeSource
FieldStructure
IndexPartitionEntryStructure
KeyValuePartitionEntryStructure
KeyValueStoreEntryStructure
LimitParameters
ObjectInstanceTypeReference
PackageTypeReference
RejectResult
ResourcesUsage
SortedIndexPartitionEntryStructure
StateUpdateSummary
SubstateSchemaMapper
A builder of SubstateSystemStructures. Note that the implementation below assumes that substate owned objects can not be detached. If this changes, we will have to account for objects that are removed from a substate.
SystemFieldStructure
SystemOverrides
SystemStructure
TransactionDebugInformation
A structure of debug information about the transaction execution.
TransactionExecutionTrace
TransactionFeeDetails
TransactionFeeSummary
TransactionReceipt
This type is not intended to be encoded or have a consistent scrypto encoding. Some of the parts of it are encoded in the node, but not the receipt itself.
TransactionReceiptDisplayContext
TransactionReceiptDisplayContextBuilder

Enums

AbortReason
BalanceChange
FlamegraphError
Nullification
ObjectSubstateTypeReference
PreviewError
SubstateSystemStructure
SystemFieldKind
TransactionOutcome
Captures whether a transaction’s commit outcome is Success or Failure
TransactionResult
Captures whether a transaction should be committed, and its other results
TransactionResultType

Functions

execute_and_commit_transaction
execute_preview
execute_transaction
format_receipt_substate_value
reconcile_resource_state_and_events

Type Aliases

SubstateSystemStructures
TransactionReceiptV1