Radix Engine transaction interface.
Structs
- Abort
Result - Balance
Accounter - Note that the implementation below assumes that substate owned objects can not be detached. If this changes, we will have to account for objects that are removed from a substate.
- Commit
Result - Costing
Parameters - Protocol-defined costing parameters
- Event
Schema Mapper - Note that the implementation below assumes that substate owned objects can not be detached. If this changes, we will have to account for objects that are removed from a substate.
- Event
System Structure - Execution
Config - FeeDestination
- FeeLocks
- FeeSource
- Field
Structure - Index
Partition Entry Structure - KeyValue
Partition Entry Structure - KeyValue
Store Entry Structure - Limit
Parameters - Object
Instance Type Reference - Package
Type Reference - Reject
Result - Resources
Usage - Sorted
Index Partition Entry Structure - State
Update Summary - Substate
Schema Mapper - A builder of
SubstateSystemStructures. Note that the implementation below assumes that substate owned objects can not be detached. If this changes, we will have to account for objects that are removed from a substate. - System
Field Structure - System
Overrides - System
Structure - Transaction
Debug Information - A structure of debug information about the transaction execution.
- Transaction
Execution Trace - Transaction
FeeDetails - Transaction
FeeSummary - Transaction
Receipt - This type is not intended to be encoded or have a consistent scrypto encoding. Some of the parts of it are encoded in the node, but not the receipt itself.
- Transaction
Receipt Display Context - Transaction
Receipt Display Context Builder
Enums
- Abort
Reason - Balance
Change - Flamegraph
Error - Nullification
- Object
Substate Type Reference - Preview
Error - Substate
System Structure - System
Field Kind - Transaction
Outcome - Captures whether a transaction’s commit outcome is Success or Failure
- Transaction
Result - Captures whether a transaction should be committed, and its other results
- Transaction
Result Type
Functions
- execute_
and_ commit_ transaction - execute_
preview - execute_
transaction - format_
receipt_ substate_ value - reconcile_
resource_ state_ and_ events